@@ -3,11 +3,10 @@ require 'spec_helper'
 describe 'heat::api' do
 
   let :params do
-    { :enabled        => true,
+    {
+      :enabled        => true,
       :manage_service => true,
-      :bind_host      => '127.0.0.1',
-      :bind_port      => '1234',
-      :workers        => '<SERVICE DEFAULT>' }
+    }
   end
 
   shared_examples_for 'heat-api' do
@@ -23,36 +22,11 @@ describe 'heat::api' do
       it { is_expected.to contain_class('heat::params') }
       it { is_expected.to contain_class('heat::policy') }
 
-      it { is_expected.to contain_heat_config('heat_api/bind_host').with_value( params[:bind_host] ) }
-      it { is_expected.to contain_heat_config('heat_api/bind_port').with_value( params[:bind_port] ) }
-      it { is_expected.to contain_heat_config('heat_api/workers').with_value( params[:workers] ) }
-
-      it { is_expected.to contain_heat_config('heat_api/cert_file').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_heat_config('heat_api/key_file').with_value('<SERVICE DEFAULT>') }
-    end
-
-    context 'with SSL socket options set' do
-      let :params do
-        {
-          :use_ssl   => true,
-          :cert_file => '/path/to/cert',
-          :key_file  => '/path/to/key'
-        }
-      end
-
-      it { is_expected.to contain_heat_config('heat_api/cert_file').with_value('/path/to/cert') }
-      it { is_expected.to contain_heat_config('heat_api/key_file').with_value('/path/to/key') }
-    end
-
-    context 'with SSL socket options set with wrong parameters' do
-      let :params do
-        {
-          :use_ssl   => true,
-          :key_file  => '/path/to/key'
-        }
-      end
-
-      it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
+      it { is_expected.to contain_heat_config('heat_api/bind_host').with_ensure('absent') }
+      it { is_expected.to contain_heat_config('heat_api/bind_port').with_ensure('absent') }
+      it { is_expected.to contain_heat_config('heat_api/workers').with_ensure('absent') }
+      it { is_expected.to contain_heat_config('heat_api/cert_file').with_ensure('absent') }
+      it { is_expected.to contain_heat_config('heat_api/key_file').with_ensure('absent') }
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
