@@ -29,10 +29,12 @@ describe 'heat' do
     end
 
     context 'with rabbit heartbeat configured' do
-      before { params.merge!(
-        :rabbit_heartbeat_timeout_threshold => '60',
-        :rabbit_heartbeat_rate => '10', 
-        :rabbit_heartbeat_in_pthread => true ) }
+      before do
+        params.merge!(
+          :rabbit_heartbeat_timeout_threshold => '60',
+          :rabbit_heartbeat_rate              => '10',
+        )
+      end
       it_configures 'a heat base installation'
       it_configures 'rabbit with heartbeat configured'
     end
@@ -40,8 +42,8 @@ describe 'heat' do
     it_configures 'with SSL enabled with kombu'
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
-    it_configures 'with region_name set'
-    it_configures 'without region_name set'
+    it_configures 'with region options set'
+    it_configures 'without region options set'
     it_configures 'with enable_stack_adopt and enable_stack_abandon set'
     it_configures 'with overridden messaging default parameters'
     it_configures 'with notification parameters'
@@ -137,16 +139,19 @@ describe 'heat' do
         :kombu_compression               => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => '<SERVICE DEFAULT>',
+        :amqp_auto_delete                => '<SERVICE DEFAULT>',
         :rabbit_ha_queues                => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
         :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :use_queue_manager               => '<SERVICE DEFAULT>',
+        :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
         :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
@@ -155,7 +160,8 @@ describe 'heat' do
   shared_examples_for 'configures rabbit with HA and durable' do
     before do
       params.merge!( :rabbit_ha_queues    => true,
-                     :amqp_durable_queues => true )
+                     :amqp_durable_queues => true,
+                     :amqp_auto_delete    => true )
     end
 
     it 'configures rabbit' do
@@ -169,16 +175,19 @@ describe 'heat' do
         :kombu_compression               => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => true,
+        :amqp_auto_delete                => true,
         :rabbit_ha_queues                => true,
         :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
         :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :use_queue_manager               => '<SERVICE DEFAULT>',
+        :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
         :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
@@ -196,10 +205,10 @@ describe 'heat' do
         :kombu_compression           => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold => '60',
         :heartbeat_rate              => '10',
-        :heartbeat_in_pthread        => true,
         :rabbit_qos_prefetch_count   => '<SERVICE DEFAULT>',
         :rabbit_use_ssl              => '<SERVICE DEFAULT>',
         :amqp_durable_queues         => '<SERVICE DEFAULT>',
+        :amqp_auto_delete            => '<SERVICE DEFAULT>',
         :rabbit_ha_queues            => '<SERVICE DEFAULT>',
       )
     end
@@ -261,21 +270,27 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for 'with region_name set' do
+  shared_examples_for 'with region options set' do
     before do
       params.merge!(
-        :region_name => "East",
+        :region_name                     => 'East',
+        :region_name_for_shared_services => 'West',
+        'shared_services_types'          => ['image', 'volumev3'],
       )
     end
 
-    it 'has region_name set when specified' do
+    it 'has region options set when specified' do
       is_expected.to contain_heat_config('DEFAULT/region_name_for_services').with_value('East')
+      is_expected.to contain_heat_config('DEFAULT/region_name_for_shared_services').with_value('West')
+      is_expected.to contain_heat_config('DEFAULT/shared_services_types').with_value('image,volumev3')
     end
   end
 
-  shared_examples_for 'without region_name set' do
-    it 'doesnt have region_name set by default' do
+  shared_examples_for 'without region options set' do
+    it 'does not have region options set by default' do
       is_expected.to contain_heat_config('DEFAULT/region_name_for_services').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('DEFAULT/region_name_for_shared_services').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('DEFAULT/shared_services_types').with_value('<SERVICE DEFAULT>')
     end
   end
 
