@@ -68,7 +68,7 @@ describe 'heat::wsgi::apache' do
 
     context 'invalid title' do
       let (:title) { 'someothertitle' }
-      it { expect { is_expected.to raise_error(Puppet::Error) } }
+      it { is_expected.to raise_error(Puppet::Error) }
     end
   end
 
@@ -89,8 +89,8 @@ describe 'heat::wsgi::apache' do
           }
         when 'RedHat'
           { :wsgi_script_dir   => '/var/www/cgi-bin/heat',
-            :script_source_api => '/usr/bin/heat-wsgi-api',
-            :script_source_cfn => '/usr/bin/heat-wsgi-api-cfn',
+            :script_source_api => '/usr/lib/python3.9/site-packages/heat/wsgi/api.py',
+            :script_source_cfn => '/usr/lib/python3.9/site-packages/heat/wsgi/cfn.py',
           }
         end
       end
